import type {ListViewConfig} from '@/helpers/models';

const today = new Date();
let currentSchoolYear = today.getFullYear();
if (today.getMonth() <= 6) {
  currentSchoolYear = currentSchoolYear - 1;
}
const currentSchoolYearShort = parseInt(`${currentSchoolYear}`.slice(-2), 10);
const idiSchoolYears = [
  `${currentSchoolYear - 1}/${currentSchoolYearShort}`,
  `${currentSchoolYear}/${currentSchoolYearShort + 1}`,
  `${currentSchoolYear + 1}/${currentSchoolYearShort + 2}`,
].map(option => (
  {
    label: option,
    value: option,
  }
));


export const listViewConfig: ListViewConfig = {
  url: 'url',
  allowedGlobalActions: ['add'],
  searchFormOptions: {
    schools: [
      {
        value: 'DEMOSCHOOL',
        label: 'DEMOSCHOOL',
      }, {
        value: 'School1',
        label: 'Schule 1',
      },
    ],
    idiSchoolyears: idiSchoolYears,
    idiSchoolyearPreselect: idiSchoolYears[1]?.value ?? '', // the current school year
    divisClasstype: [
      {
        value: 'class',
        label: 'Class',
      },
      {
        value: 'offer',
        label: 'Offer',
      },
    ],
    activationStates: [
      {
        value: 'disabled',
        label: 'Disabled',
      },
      {
        value: 'enabled',
        label: 'Enabled',
      },
    ],
    isLmsGroup: [
      {
        value: 'disabled',
        label: 'Disabled',
      },
      {
        value: 'enabled',
        label: 'Enabled',
      },
    ],
    isIservGroup: [
      {
        value: 'disabled',
        label: 'Disabled',
      },
      {
        value: 'enabled',
        label: 'Enabled',
      },
    ],
  },
  columns: [
    {
      label: 'Name',
      attribute: 'name',
      sorting: 'asc',
    },
    {
      label: 'School year',
      attribute: 'idiSchoolyear',
    },
    {
      label: 'Description',
      attribute: 'description',
    },
    {
      label: 'Group type',
      attribute: 'divisClasstype',
    },
    {
      label: 'Source UID',
      attribute: 'groupSourceId',
    },
    {
      label: 'Creation date',
      attribute: 'createTimestamp',
      formatter: {type: 'date'},
    },
    {
      label: 'Date of last change',
      attribute: 'modifyTimestamp',
      formatter: {type: 'date'},
    },
    {
      label: 'Record UID',
      attribute: 'recordUID',
    },
    {
      label: 'Activation state',
      attribute: 'disabled',
      formatter: {
        type: 'boolean',
        truthyLabel: 'Inactive',
        falsyLabel: 'Active',
      },
    },
    {
      label: 'Activation date',
      attribute: 'divisStartdate',
      formatter: {type: 'date'},
    },
    {
      label: 'Expiry date',
      attribute: 'divisEnddate',
      formatter: {type: 'date'},
    },
    {
      label: 'Scheduled deletion date',
      attribute: 'purgeDate',
      formatter: {type: 'date'},
    },
    {
      label: 'LMS',
      attribute: 'isLmsGroup',
      formatter: {
        type: 'boolean',
        truthyLabel: 'Enabled',
        falsyLabel: 'Disabled',
      },
    },
    {
      label: 'IServ',
      attribute: 'isIservGroup',
      formatter: {
        type: 'boolean',
        truthyLabel: 'Enabled',
        falsyLabel: 'Disabled',
      },
    },
  ],
};
